## Subresource Integrity

If you are loading Highlight.js via CDN you may wish to use [Subresource Integrity](https://developer.mozilla.org/en-US/docs/Web/Security/Subresource_Integrity) to guarantee that you are using a legimitate build of the library.

To do this you simply need to add the `integrity` attribute for each JavaScript file you download via CDN. These digests are used by the browser to confirm the files downloaded have not been modified.

```html
<script
  src="//cdnjs.cloudflare.com/ajax/libs/highlight.js/11.9.0/highlight.min.js"
  integrity="sha384-9mu2JKpUImscOMmwjm1y6MA2YsW3amSoFNYwKeUHxaXYKQ1naywWmamEGMdviEen"></script>
<!-- including any other grammars you might need to load -->
<script
  src="//cdnjs.cloudflare.com/ajax/libs/highlight.js/11.9.0/languages/go.min.js"
  integrity="sha384-WmGkHEmwSI19EhTfO1nrSk3RziUQKRWg3vO0Ur3VYZjWvJRdRnX4/scQg+S2w1fI"></script>
```

The full list of digests for every file can be found below.

### Digests

```
sha384-yKHBn4kKwW+cLQsn0fyaWyVjoXRIUe7/lWXGYzQhay+47RWC6+0Pr2sm2LeLEK2W /es/languages/abnf.js
sha384-BeYdlHmYfSfJIZ0BwNBIg4pHN2Nbad4B2nSb9m9bHEM6kacPk5/FlA5ojzShEDLP /es/languages/abnf.min.js
sha384-+cjJSDOWSAbotsSXpQboVeVHgAguvM2DEPMB8jVhRAHSkx3tOhtw3kwIi6aLwrix /es/languages/accesslog.js
sha384-vx1I5PIkVSkAHbjcpmdlPQm/QmGrcmaqNFopgmjZIaCXdiSOxL84U6Vcccfmf+p8 /es/languages/accesslog.min.js
sha384-VEIOYplsgkUaj9yR5ZPCFiFBLjuX7pC7a82BJAVcGWzCCXsXkAI2RyC894B/9gkk /es/languages/actionscript.js
sha384-NRvcTv2Q4lLgjyqBi5tKLK9bHUJh6OJjGeU9dZXroNUOeYSc7ZN2zSr5lfFqcI1N /es/languages/actionscript.min.js
sha384-pF4tKJkttvEq8PmfdGIkZ21zzYjsMo+BOtKtwH+wsvDxCh/crF5H1K8ld6hE+n+9 /es/languages/angelscript.js
sha384-oVi1X3v1jp9W9YtA/mUcKgEi43Apn1XZwJ7vBkHiGZoK4V0b95pEN10eUjntt3bT /es/languages/angelscript.min.js
sha384-o2RvzuEpU78s+xoEWs/++kMfb71T2QoVpd5kcyephebSrCF7IBl82kpINu7hXFCB /es/languages/apache.js
sha384-T5Wi3CdvOgNTDa/TQF3guYZxiCaiLFKzgYxX57ZCt1rVax+G6GP9EOlNdg8spAUs /es/languages/apache.min.js
sha384-SXyBDWbbsvVyOn5TICWCahSdE/E+YqByrDZhk5477SMEixaEUJr8NzFO9Qjyhsin /es/languages/asciidoc.js
sha384-t9QnTos94FrBBrAC7s5wV5c/I48x4nw+3vsiNa9XwkyyQih5RbUUSqt2Gd4uSfkG /es/languages/asciidoc.min.js
sha384-SkjbjI/6t3oYi7r9yC19GSENsMppTyATcM0Hb4Ro98WDhtVDdEV/aqh7NKwKZfW6 /es/languages/aspectj.js
sha384-OwqoHxcABDMucpDcqqtUFQOvCjXVTurrsakiRwMZJGicVyyEYx+zw3vsZmwbSEVo /es/languages/aspectj.min.js
sha384-LSrDnkIuDqEJU7373IMv7W2dPxpRwdQDX+5H8SuLPZTaJU345g7Wu+bxhnvwt97j /es/languages/autoit.js
sha384-aRhpIolQegOq4Z1SMG3olwIyLahejSMO3YFexuiuhf5X7w7AK7E78fCnmrsBAN83 /es/languages/autoit.min.js
sha384-u/MnWLPAdhUSLvSy9g3lRTFAwZSiveQjbKCTRw58BJh5n/RQfyyiwweCohM8LeSM /es/languages/awk.js
sha384-UjBtWlHRGRibzEDg1rIFn+Q1OGqWCyMh3RkUN9+hDW27sIB2j8mcGvxmkk8l8LVM /es/languages/awk.min.js
sha384-uBlc/xEFeDxZmBU7K/YWwi3ryXQrLQCAY2K1Dl3OD2DaAQBZZTt6Ew3aeDP20ix0 /es/languages/bash.js
sha384-4qer4rJCVxZjkwD4YaJfOnT2NOOt0qdjKYJM2076C+djiJ4lgrP1LVsB/MCpJSET /es/languages/bash.min.js
sha384-EwAFcMMnNYbOS/ABVtPlSLENfB27fQSxa/eUw9xWLejr7sWWPcICSoHJUxNVwhgI /es/languages/basic.js
sha384-3EDvjyClCK85gMCNUIHh/H9+K30vwYJjkGmjdUKpG6bGxahP+dSc+HRtXadT8eUD /es/languages/basic.min.js
sha384-O198QQIaZTLpzOQoKcadeuyu7LZ0LL1CquIxT7uP1wieihsi0unwrj6XtXRMo9Fq /es/languages/bnf.js
sha384-NAnc3ReMZ27obXeSoozcO7isebTvT46UVK8K3uNQekaf0nmAcMkObTVPVamXqAbg /es/languages/bnf.min.js
sha384-0OZaeLK1yb5eP3nW4y0JP1fVharSrsuv/1mkI/6/8aRFm9laYIWIMXjCOqu+vRW5 /es/languages/c.js
sha384-G7WtwjMBNGrPly3ZsbPhfnT0v88hG3Ea9fQhrSWfzj7cNAsXsU7EKMQLyLGj7vTH /es/languages/c.min.js
sha384-GeyG0cyMYEfzVbdKlcw/s0gOcWEbdOeOOxz2rX2i6UpFrNG5BxtiF4t/AOCSVWP9 /es/languages/clean.js
sha384-7KVG2qZ5ZTMB8I7DeWVIsjFanugFQSryvuNwhwxN1pHBMXEU6LYgpU1ZTvvIs4dD /es/languages/clean.min.js
sha384-cEeSepkmM48Qe83yyTwFo/xnYlyD4ZO1tXaFbukowK2pPsea3XuCQSOwKnVmDrvC /es/languages/clojure.js
sha384-trRP8CnzW/SSG6kXpTUGPBhUS/tOwRQ992lsIs6/zZ9FueaoJeINicKwxLLVIZKV /es/languages/clojure.min.js
sha384-vFaFU6BzOmN6+nnjN9PVK1v19gtBl4CV6XKEFd8Z7TocU260nxSAfaxnXfMUzT95 /es/languages/clojure-repl.js
sha384-k1X+fuSMpcR5xKe3aKGlyhvbYhLrDZlV/idD0dyH9Ez0QfO+xkhxwQTdTHcsu/ne /es/languages/clojure-repl.min.js
sha384-Wjwd1YEG/PYlkLHTWIx+RlPK6XboMN3bEpveERJ8D8Z4RaNE02Ho19ZFrSRPGi0j /es/languages/cpp.js
sha384-Q4zTNH8WsDVdSZbiZtzWS1HmAUcvMSdTmth9Uqgfjmx7Qzw6B8E3lC9ieUbE/9u4 /es/languages/cpp.min.js
sha384-Ia5nC6F+dWrLhnUoEIdtBywPSh5QJfX++8Ohr9xEdRWtKrngTEzM+w9MAs3OkW0M /es/languages/crmsh.js
sha384-FWGvxRI9DV+fT+c7GmrgMrdY0JGqiYLXDhLispUSnhqeHMfnVQXae2ICGhKrsyVz /es/languages/crmsh.min.js
sha384-Sp8E1Lb9fNhbvqBiogM60TCgpAIwYBi8WbHhIHcXO0bR5Z+9LeYwpDa1gkjzU99W /es/languages/csharp.js
sha384-huUb4Ol37G1WrtGV7bn1UArXcJSjD4tQswMGzgpNZYAPxR74MHTqW79z1dXWMvhk /es/languages/csharp.min.js
sha384-DA5ii4oN8R2fsamNkHOanSjuN4v7j5RIuheQqnxMQ4cFnfekeuhwu4IdNXiCf+UU /es/languages/css.js
sha384-OBugjfIr093hFCxTRdVfKH8Oe3yiBrS58bhyYYTUQJVobk6SUEjD7pnV8BPwsr8a /es/languages/css.min.js
sha384-nJZn4t0S58K5MJ/2BOmgkTC8TtBWB76ykEKIIzb8sUxT3h7ouZH5Ucqnr9MJ6Bry /es/languages/diff.js
sha384-OIJrZgyhN1E6e29B9M3gFPtkR5JgXpls8h5D2bNzBxQ8Ncwxzfjedu3/0jZEe7S9 /es/languages/diff.min.js
sha384-MIy8GI9hoOfmj9i8J9ET6pQfhZRSy2avHKawR4XrLC/TA0KTWF2UvSCfRGxtC9uk /es/languages/dns.js
sha384-BZdQkDZ1ac9zSg4XmtL2hLKld98ttTuqoM6CWOjKIrT16NkmNSlAY/1rK48DQjqy /es/languages/dns.min.js
sha384-/wYGIAWwdVeBvXFBq3HUPpdw6KUhW3wMMXruGXWjhlYT/IruTWojBeoPUbpGXaf5 /es/languages/dockerfile.js
sha384-DQdaFTXRCa9EQdAkBCHnMAhAomUgizSpJPmuCzoaDJMAshvgxlJF5d7J/ysvc6f/ /es/languages/dockerfile.min.js
sha384-3UnsR8EJG6uDdxeyWqOyV/M9UI5m8cCdd4rxGUokKsQeslxONZ1n7bef9Li90X+d /es/languages/ebnf.js
sha384-jQuTDS10jALGEitp2l3m/2rTJZKkqrZAYnpPu/l1hGq+/7OdVpCLIZFBsqeyLD1k /es/languages/ebnf.min.js
sha384-EzHQEbAzbwb1C9L6vi8Q2bMXMmOj4MKOUCn6OSa2NzRqDqVwGXfSVrylMO9zg3Oc /es/languages/elm.js
sha384-TpeiEEW/MM+zgu0X/O26T/xMSJtm4DAot0uQlZ73FP66AgdlqWO38C/GqpVwo58Y /es/languages/elm.min.js
sha384-+Knm0ftuanxtMyjy6F060PlVQeYLBYyhRSdUrERbAjlJcHv2XTwe2gbWB3omFV5h /es/languages/excel.js
sha384-R5EduCTSW2/YlL/qKgN18FII8GE9/D4fJnSNpih/gNUzPDoiu8intnPNdulWELkT /es/languages/excel.min.js
sha384-Eu4oFaj83/CnftNCrrbzx9NGj35Fof3bzIXXTWVGx3Cm6d47o+82IjjlgfuBjkin /es/languages/fortran.js
sha384-tfyHooH7hV0/4S0EFsbgk/H9JZRSCEOuZSUOLQ6udPcWeHT17xuRlhnDlAPd1VnT /es/languages/fortran.min.js
sha384-PlRlnTHneMtJbkTa3EfvlRQdjmWK3/QGPB1XcD9Gq81/BMvsOahBaxCiSqOPDtnv /es/languages/fsharp.js
sha384-B1ZRrYmfEhHwYo+zuVPZpMfzy6cQt14Vvsbz0ZgQaJfZotA1AjdYP0C+zvN39Czh /es/languages/fsharp.min.js
sha384-XcoPs3a4/IR69b/Dm+Q+u2pZ1mkg4OLQY3nregS20Zi93M17jhVxokvDNVBKwocg /es/languages/go.js
sha384-27jMAcMfx5pzlW2ntRUz1R22f43tLLOnYyDHss8iJBUi23iVzYrxbwQKY+LPU35B /es/languages/go.min.js
sha384-ag2M5Fq1/MSu4sZfThH972/0MDhWwFgbBdhPtX6AqlRY7s2wMioVLNhhKrExeCHj /es/languages/golo.js
sha384-Q+qImPh7I/MiA1r03Kj40Ikpb6PS1c1seZwQHBynw9bPiuSIxRSTHV5zkRZl4OYc /es/languages/golo.min.js
sha384-3p/2cG3HUNx9rqLOXHgKKfr/Mqv95R+00Iii0s3wgdfWWJVhKm5jEO6/kdL1HIJw /es/languages/gradle.js
sha384-+ilwPpCDudisnRgBeI+XBD7X3bLGw6EZnosF/W6iT/5YyGn0Qwjef5JIZXBkdrnr /es/languages/gradle.min.js
sha384-6chagswO2Kdpzx/ovk65U07pdppN0fIgbg4AYmfufy3hIn+8GVZMvUf+dG+NVAn2 /es/languages/groovy.js
sha384-tgywtm20fLQUu0uIXBr5KDIjyHpfZuyM4zKiakHHNsi9zinDSqPIr/FVjREnEWmY /es/languages/groovy.min.js
sha384-7m427rj9OYl8KKObOk+aD0QhXmqXy6hU/sHGS6OUwW9hRiiHvr+tLTbLiSJYbIyD /es/languages/http.js
sha384-GdKwMgTrO0R3SPXhm+DuaN3Qr7WkqYmmTClINAGPuV/BUPE9WUI/WnTEntp522Sl /es/languages/http.min.js
sha384-7hMYwsnoFLW0Wnjv4vRnZxuedW1tCz7/pydl1b9w3fg7B+rldToCjqzXwCRHUE7C /es/languages/ini.js
sha384-LDu6uT3diI3jBUJtdoGFa787cYlVrR+aqFfmW+kW+TImOkpVe+P5LBdDzydIHo9Z /es/languages/ini.min.js
sha384-WFJdA9Hz+G9NQx5vPba/tcGyIibm57UkKVY32wNB/94iT2FmPma5W7gY8p2l6qps /es/languages/java.js
sha384-coaxfgI2lKuDqSxfMlfyPq5WM0THaLGyATZHzaFMrWdIbPcLdduuItTe6AmT/m33 /es/languages/java.min.js
sha384-WCznKe2n87QvV/L1MlXN+S8R6NPUQGU34+AqogMuWGZJswSD6rt3Mgih+xuKlDgm /es/languages/javascript.js
sha384-eGsBtetyKPDKaLiTnxTzhSzTFM6A/yjHBQIj4rAMVaLPKW5tJb8U6XLr/AikCPd+ /es/languages/javascript.min.js
sha384-2+pPAn1jFSyw4e3p0BW059mD3OL0XmhYyp0f1MXYZkTsatnxTtKwyc0cWAFG2otO /es/languages/jboss-cli.js
sha384-QxgUyxVKlIKoUKhpv5x52u4Y49438L6rIge8mH2UqBI8S7aCKL7kR+1ulkny45ak /es/languages/jboss-cli.min.js
sha384-12GbYFzdyZCSmfBTmO2CR/qE89K5uE1PEuJ3QUwXH0Q9u+uoLNigjH9dG7LAxxiI /es/languages/json.js
sha384-+DT7AtubDhVDciRc6CgjJJRsCt0L8NC3Dh8n9Tj2tZWU8rWxDIj1ViubmUDn8OCY /es/languages/json.min.js
sha384-tsX5LI0gdW2Xk9ZMsj7B2vRchm3jC0zoc1r99Z1377aXFJJXimRtRYQprUJpSuu0 /es/languages/kotlin.js
sha384-mfmdbPhLobPr5OJzSXlWHDQDymRYyzedurWjJBvKVhlQGE+Jz/pN3D9lPEBIkDK2 /es/languages/kotlin.min.js
sha384-JZ1yKn4lHbd05rOuRoUSoCM323D+X3s7vLYhESynzVpdWAFu5JNp6chDl5N9uc1c /es/languages/latex.js
sha384-dDJ50ltJ9VlfSOzSORI0KSNPcRIpLy1J0BmtdQGXBEY+7f57DAx754HVffzmWqC2 /es/languages/latex.min.js
sha384-UO0mFYPt9ryvStqH+HMYBbv0OMe69vo7jHagEW7RSgUwmWsO+BQsQ9il4JvEyb9U /es/languages/ldif.js
sha384-epMw7vS/pc3vOOz4l9Bc4ivmcMrwtBmh3ZRGLa/auLNCxt6IJAJd2HtrsYwa6q2Z /es/languages/ldif.min.js
sha384-iBzB3Gn/ezqfaxd3xkqjVlWlUdqCAcOUBIjD5IQGs9p7tbFNU8ymlgKpDsGRGaDQ /es/languages/less.js
sha384-04z6U6c1rUG3NEMdXE8dOimK4VJx8yGR1D5qKHgS7319t9s27xfmtQLQKC6jDUuY /es/languages/less.min.js
sha384-UgQTewauLJ4EgpADCJ99JfEtiPvw+fyaSrY1gtCVBviDNG7yCH5U7qutYptSfYk+ /es/languages/makefile.js
sha384-aUXBqKsjOzPD/W+hccF21KKWmWts/CrY/lWGJU+dAcsKtuh1/XtyDnzfLmqy/fV1 /es/languages/makefile.min.js
sha384-bWwkdmOCj83zZ8/m+oPD9goRMhrPCb25ZA6aTyg7vcsq9IpuyED38kQSw1Na4UTZ /es/languages/markdown.js
sha384-SqGSUq0DMQ0OUQnQnTuVDCJyhANd/MFNj+0PF67S+VXgHpR8A4tPsf/3GoSFRmrx /es/languages/markdown.min.js
sha384-KW5m+lJxeSte36eSdXdF6RWKt1rP3PKVAblsiDORE441O/7ONXso3W4FMiQM7DVo /es/languages/matlab.js
sha384-gU9Mv6FEG6RVi/d3cgP9RYHSdGMkLi/gYQCn7smdbY+m1qDCN2paZoONWRk0tBP4 /es/languages/matlab.min.js
sha384-ohJ9Jj8Mwyy7EntP4tGMJEtH90WJNKu2C4l37N1kqyTHgbRJyGYUgFe9z3qy3/C8 /es/languages/nginx.js
sha384-tpFPEHvbpL3dYF4uFiVNuCUF62TgMzuW65u5mvxnaJYun1sZwxBsKv+EvVgv3yQK /es/languages/nginx.min.js
sha384-3ETIPQZ3mDkQp0yO3vWqaxcOnISPBk4oE4DrkgRfbMW6rhFcvu7N/P8tucGbapAC /es/languages/objectivec.js
sha384-eSkOKizj8aZA0WJaMmTJA3uqUtTkbZ7PXAADzDquzxCLyb1BMNgF9cn7/FIu0wFR /es/languages/objectivec.min.js
sha384-B+EjdRTJfuRQL8OfQPSh3FpJXyftaETF0bCfUNAm34365HyQ0yM6cjh+8qYsSEE2 /es/languages/perl.js
sha384-kW4vu/krgDKKOlEd71XhqvOJNxZuQ9t5Rwutcxm3/zfujAXe08IcLMX5Al0NGE72 /es/languages/perl.min.js
sha384-6eW/GwBjd1p/IWWvPhtlCq8ZV/viLec5e+CL+RdqEVMAfnyfcuqhDzNA/eADmRK0 /es/languages/pgsql.js
sha384-zOSNwldQX3ufsVxttzdDmDOl9B8zrMIbr7l0ixGfdle/Ree4OxUJK7kQjCDqT45z /es/languages/pgsql.min.js
sha384-JBkI+6623OoC1qCgG+MY/Ta0qRYSzTDH4NGMA+7U8RNOjkh7geFvYpRidvdHs3zT /es/languages/php.js
sha384-6Znh5S5q9F0hGNMtdaihFL3RJeMqL1a/UecjgzaBrhoxe4sjd5aiEOgokt7blhSW /es/languages/php.min.js
sha384-lbDR+U/5ETRHb0r5ElxxVnAt95EFhleDFZw7nkVPcRk3lbX9NsT/Ppg37FFNiv8+ /es/languages/php-template.js
sha384-dGJwrvnfo/JaY0lSDtJuhB6XXPmL9hSqOnIYndlN0eE1PoA9FFxd+VtaSfcacNDA /es/languages/php-template.min.js
sha384-TTDGPCrk8Dg2oW6NghGM5WJQPbi34BdYJj6yfsDiGXlM5os/SebXT6KzATp19rzo /es/languages/plaintext.js
sha384-XXx7wj9KPm08AyGoGzzFKZP2S7S+S5MbKMPnQcWUyhJ3EjHvLuctK/O1ioJnG2ef /es/languages/plaintext.min.js
sha384-PpU3S+yZJ1Gj2R7L/OgTgkKELQOf7F1VcbaAEJwSFSM9lw2ON2wxq1FvUcUlm9ne /es/languages/powershell.js
sha384-pBczxETXXX/Ne92jpBviT47DPiv27FLNtvs0aMZH3W7rYXdwgf1gWg3pH4NmNC2V /es/languages/powershell.min.js
sha384-xIPm4YZYbv1mWtyahwtQduBLpJKaWd7HPwICo60TqOigFDvrafTSdFhR8OJh+cmv /es/languages/profile.js
sha384-KN6bgPY9F1QInwObKCM1rAyr3deHf/g5fYoc9VYe1dY4luss3KrzYoDcdI725dDy /es/languages/profile.min.js
sha384-F4RSDVgBBiOzTXLHkMeGKJDgpdhWDUb6NCDoz6BYnQohs3NkiWLi+wTlBgsb8fZX /es/languages/properties.js
sha384-Drd5kfuBp36sTS9lcJ+ai2UhYgBwhpYsRDl2T3useOowrqih3gTCBLSQI3M5lQQm /es/languages/properties.min.js
sha384-PrExPWxPTKzcQYHa2zx+ep07BBrr553zoc5lfxEdFJ6LyMpaaGDGZFmBt5wp0zO5 /es/languages/puppet.js
sha384-AD3TodU3dq//GRWPVK0bQi/Px1bVpPbCnAmqJ5eh95PeV2hmitDzKvL1PI39Q0n/ /es/languages/puppet.min.js
sha384-1FJg+comSC4nXSCbkwUcXDKZOZHO2wImKGkjEJZspzTdQAD0zTZNCllViL5DWcWU /es/languages/purebasic.js
sha384-JrWCxwBg3eui2fINXeS94URdHjdsdop1UkpW9t3kFMya0i4jXubaG9QZKghbzQ4x /es/languages/purebasic.min.js
sha384-+5oyk7Ed3OlvEWGj8xracq/6e52BScKUN4kxcreNwB7kfRTVsAMs/aAJM58dzIFN /es/languages/python.js
sha384-ND/UH2UkaeWiej5v/oJspfKDz9BGUaVpoDcz4cof0jaiv/mCigjvy7RQ7e+3S6bg /es/languages/python.min.js
sha384-BSeMSSkpHXATzXVnQDrjF2DPTOBSrKP8QqV0DcEVYa5k6JK9CSYxFKyEhj+Kqnde /es/languages/python-repl.js
sha384-sW9zIYfNc+qN/lya5oAmIdFlVbXjPLcdYkPSdRMpxO/xI2jbDW/Q4Etvx02DFOmf /es/languages/python-repl.min.js
sha384-vs4jXytP3N3d5zRX15Fqc4u/kDI5jDr3PNYIvQ0mmmoU+o/yxJfu/+VYme6qIOa2 /es/languages/ruby.js
sha384-O4a+vELXT191NhKLE3TR5WQwDmQZ2izAhb2zETRxcPSXr6CJruqJ4a+GJpDlaqCF /es/languages/ruby.min.js
sha384-I4aH0szMeaCbcs8R7dhxA3p7ZBL/HFxnD5Gbz6l52kIrd/igSSFi/9sJCykNuL52 /es/languages/rust.js
sha384-1vvSh2x0WCtPLbkTMqNuf8JSZw8N5bSo9oONZ9vqU8NOBHPIuKt+kFdC8G5nA+P1 /es/languages/rust.min.js
sha384-4fBir7jJHF8vQZyZ+AljsNm5cbq86jL9AITYmJdNK7zrCGDgQ+KSzDM9UdqYQehp /es/languages/scala.js
sha384-5KqbJwOue0VrSIbMNJrkRcBOzNPBxlGPbrTdH/biCYczeCVi0Ethcg+fr1RXfH8i /es/languages/scala.min.js
sha384-dzLjhd9nNJH62idgKI1vZEKHRBtZXSgwWQdPR+emG7tfAN4BW2g+A5Xs2315Uxii /es/languages/shell.js
sha384-RKUoelG22/D7BV/bNpoGLNzdTgWRf/ACQX7y4BGyIzK6E+xUoXtm68WNQW2tSW8X /es/languages/shell.min.js
sha384-rBAFhyrcRcMNbVJ9g4k5y3eQDkjGdgoOb3oTWTbHgwyUgUNv3CK9wLsGy/d+52oa /es/languages/sql.js
sha384-8G3qMPeOeXVKZ0wGzMQHgMVQWixLw3EXFAcU+IFNLRe0WoZB5St3L3ZLTK62Nzns /es/languages/sql.min.js
sha384-GeSC35L2abDL10oBSI0dwmV6CU8FxO8EJn5fTlIaHC8o57sZ28pgPCzDRFfjo410 /es/languages/twig.js
sha384-Bll0N6Bv3PBNceR+4FI/xj/vKUrRYkGyy0oHArQg7yjocZ4goBU/MlbynwkpxynM /es/languages/twig.min.js
sha384-CS3qiWid6Sod3yAiQwgPzy2ZerR00u/cwhnMxQrETuI74o006r1p5qj1U9Gdo4uD /es/languages/typescript.js
sha384-HHgazax8ozQ9RDWlJQyaFzaTk/OgTFRVHH+lcaYInkE8wVu5fnpkqkB3KUdzKcvE /es/languages/typescript.min.js
sha384-ckZPeKyE8cW29gT8AxdZNWMC96H8wZCpBzPVkyvuqsGIDvYIzEyxJcckwbv/afrk /es/languages/vim.js
sha384-8kEj1LOKOKcz1ifO10aWlws8zNCnrxWFhHS5zWENNU+dOB/z0X/X31StZHBTQ64Z /es/languages/vim.min.js
sha384-OFoR8IZ+CFwcY8plx8HSDZNoCwLxc701CwdNGfoIEhSgwAbwhvInaxnEi3HYTt2Q /es/languages/xml.js
sha384-yFd3InBtG6WtAVgIl6iIdFKis8HmMC7GbbronB4lHJq3OLef3U8K9puak6MuVZqx /es/languages/xml.min.js
sha384-u0+O9QCLR6/pA7Fe+dFLXetRDvhlzU2oz5uA5hOJFE6Z203sMUWkpEU+MAXhHZy1 /es/languages/xquery.js
sha384-ykAvQddsMz2kd8fP4oPW6ZvTLCXUu7Z5PLw13CLPULaTYic99di82Qpz19z6pP8Q /es/languages/xquery.min.js
sha384-MX3xn8TktkjONV3aWF6Qn6WZyq2Lh/98p0v7D0qEoJ4WLdYjoAyXF/L/80q3qaEc /es/languages/yaml.js
sha384-4IiaMbQ0LBiRJYBGoAXsN+dV9qu/cGLES6IuVowdeCu/FAMY5/MQfD/bHXoL2YBb /es/languages/yaml.min.js
sha384-tB6wcb0jFMBpCFIAQnS32ndPHKfUOLC1JVwcDoEqzoFAetXHqtDiaXVAXaWbIO/a /languages/abnf.js
sha384-CMT+D14J35o3MzFS0PS+C2Uxx7NsC/9LDa20e/cSnYPEuKGR9IaO/Y0E5pN2qeFJ /languages/abnf.min.js
sha384-wWNyZqG6+Tb1rRskCP3qZjTwRbb9AXwkj1emJa1QFm/wqE5WZf93bjR9IAgcxXD7 /languages/accesslog.js
sha384-BF61I4vqlKI+Z6dQUyVuqQEE9RSYZWptePUuYrYLfxlYJT6r9qNemzfyAqJIXHRJ /languages/accesslog.min.js
sha384-64yZI+ex6eQB5avYBnQpSvoc8CBbbDpJsn928TIAawsNc7Pvzy6nJeD1/bau+SSn /languages/actionscript.js
sha384-FNkevfMdwlt5PY/joajGDoOOJVgElZtmde2301WYvRzYu/yhe/28OLBDxs3JsITM /languages/actionscript.min.js
sha384-LXjB3zNuNyP8objcaLtrzCUb7LxZVpkyc5A+Nt/lVkW30MXdRRBZUYAhdfUYakEp /languages/angelscript.js
sha384-SXlbgREKQvT6vnCiz9PJKTyS3FHFLPIj0EKXiMUEp1Xna6/gOL88RRVo/AsE0mR/ /languages/angelscript.min.js
sha384-hK+QzfKnkrwE7Fgc3q6lpKfnWWKMecpkQObMVOPiwopZiJni16bBGVm37SMGcz6G /languages/apache.js
sha384-bvrESIqIr21pkx86VgiN+Vfq8sRk/6xTxMfbo0PDENLfqYr123El7PUCzqJmir4P /languages/apache.min.js
sha384-HPT+hE+CRAgt+UgsOWKsXyconKSjRIbAxiWxwmmQ3L3ijW6pi0tvaMpnT0vNORvu /languages/asciidoc.js
sha384-sf6kQzw438VELcTHWkS4YdEyIzCPQbGZLke4v5rtAIBrnGsuvCILPWGeIcDIVLmX /languages/asciidoc.min.js
sha384-w9bJkgHQEknWci4SOht2ouVSzVC3OMASR1nk+8IWcFKGiekjCBVPCpoq8a5ZR7RX /languages/aspectj.js
sha384-0thj2cy99KLUBB/ftYmPYVhMdSjNZZd3hG/FnuWfshVDkQTvgWHF+n+PdQ7zwuW3 /languages/aspectj.min.js
sha384-2Gnsm7pZAeqgMiMEEyK1CzEygSGNc5qQSZ76rJdHZTNzf8hOyif5IOg0MpfCbTP3 /languages/autoit.js
sha384-BK6bQW09cPx3jR/N3JQ4FnK2LI9Y3b3zrDosiReW5PlhzemA2ZPeOReQVk4Btsai /languages/autoit.min.js
sha384-xfaX9UdEVoIlYoDcsxk5OO1ddyQ0fl/BmWflf6SctNce+UzNDEimoWGmLbk0FTPg /languages/awk.js
sha384-+kQeWvlXeWctdKQQ8iGrG1JdmiKRJHAqofS2vKNnJ24H25HqMhb9kIQC3NYrsoch /languages/awk.min.js
sha384-qbbaBGYYg7PdopdWOGj8KdkBosUDY5PAe3aTMJKTqWcriPBJJzCVu5BlwNEwqr9U /languages/bash.js
sha384-ByZsYVIHcE8sB12cYY+NUpM80NAWHoBs5SL8VVocIvqVLdXf1hmXNSBn/H9leT4c /languages/bash.min.js
sha384-KNVj6C9bNyJrl0feAi64iBCZkXxoTQxDbAJqGlVos5lGlSTOHd+zE1xQgkPFoH4t /languages/basic.js
sha384-KfOKKkbUp6gWmUdMPNCj5Hqqmf9Z03BTs0GnM3hyrYlNBYXSt4O527wBkKrgxiIl /languages/basic.min.js
sha384-OAKWFtHJoImtM2eNcq0MhM94c5KQ60D4+qs2hEy/3fsRlFDEi3Szh+OZri7jRfip /languages/bnf.js
sha384-79U3FFsfVk8mFdeTuAdp0bLlLWAZ2Mh3zYTr0ndb1luM3RGpgFFiyInsDU4p4VqC /languages/bnf.min.js
sha384-VZxKf0mjKYDwZIgrW+InqDfJ0YwYUFEMw/4YmpV1oKtVXFVmVq/Ga1vgq6zKTUqS /languages/c.js
sha384-mWenE7UXKnmYRcJ3mh+Os3iZ43BmFf9x3AZMM6gi/2sT6vxouPWspbTdREwWDO3w /languages/c.min.js
sha384-do0ugLqbf8wuLcIgudpuAq3VDRfiO/T/qRI0AesKyhky7lRT/5kdkPqy3718nmT4 /languages/clean.js
sha384-YuLT3q/Co5XpnHSrXi+r14qWIfXfFw4yd88JywxmeJyorSwjjzEo7wMPfrd8tdKp /languages/clean.min.js
sha384-k+XDUAVhlUtu9Gv3AkKvB9gL0WtZTonn6fFtlSdKn1+7U6yNLgRLHg84pXr4hmp/ /languages/clojure.js
sha384-01/jwK07TwTjPcx55RJ1V03zqCdkEK8QBmgLSbcgcyl1uZ1AwjuSmufE481pF0nY /languages/clojure.min.js
sha384-ay9bRwR4f9M8UI/NyiGJ1HTv523B5GEn2wlWYh2raRF/1TG2wPpnLGiDXSamWhNT /languages/clojure-repl.js
sha384-JHMQSU8sCMCdL753bS07Oioz0pIyBJnH5TRJy2QIQqDPil37Ezn0fO8LBx+F6/Mn /languages/clojure-repl.min.js
sha384-J4Ge+xXjXgzbK2FP+OyzIGHLfKU/RR0+cH4JJCaczeLETtVIvJdvqfikWlDuQ66e /languages/cpp.js
sha384-LMyrRAiUz6we2SGvYrwDd4TJoJZ+m/5c+4n4E64KVkfWFcZdlrs4Wabr0crMesyy /languages/cpp.min.js
sha384-oa3mX3v3QJKQk4D6BB1rIniLZbz+eTWMQuHXqBCLySe9o3KZ2pfkZqmWU0VE59ey /languages/crmsh.js
sha384-zN7rKt9V1OgNoMrsbrSGe1x9oL1N+6SczPLqhi2vRQNealAEGZBqROnVqMnc5FKL /languages/crmsh.min.js
sha384-8sbRwiU8Ar2M7+w//1u7YiI1e7KsmB4k3QbW/m1IW5FVH51HiOpR7g5QGE3RqTNi /languages/csharp.js
sha384-wWP4JQEhRVshehTP7lUMDn3yhDI2+398vN2QW5LBt1xIpK0Gfu4dPviO8tP9XRo5 /languages/csharp.min.js
sha384-r9czyL17/ovexTOK33dRiTbHrtaMDzpUXW4iRpetdu1OhhckHXiFzpgZyni2t1PM /languages/css.js
sha384-HpHXnyEqHVbcY+nua3h7/ajfIrakWJxA3fmIZ9X9kbY45N6V+DPfMtfnLBeYEdCx /languages/css.min.js
sha384-d6WNn2kPYgdezhgRmGehSkGVKwbg+ImJrGTA43yYg8VsBqYW5TakSDi/jbVjzqfD /languages/diff.js
sha384-yE0kUv4eZRBzwnxh0XmeqImGvOLywSpOZq2m0IH40+vBtkjS716NYEZyoacZVEra /languages/diff.min.js
sha384-fqA1g+qpOamYxlJhxcdB70bFCuVXyCGBytozVm1cBnm4XM+eGfkKcY1eZST3noz4 /languages/dns.js
sha384-ThDmUDUbkLHd3YjqnAKK6DGmCqm/zinzT9ezHFHk+GPnKaM0dvEM3KfFeoQUt8KH /languages/dns.min.js
sha384-BBTUoNxAh4TWINjb22cp1mRwwVdcPyF6zzXZ/1EvQ28ls8EIGhlCKeLav689vLdl /languages/dockerfile.js
sha384-H3wUmCndJNBOuIIzcLSr2zLLZYs8PYuw6qKyENk7THEnYQJvOMDBu42P9XsJSRKw /languages/dockerfile.min.js
sha384-nqo0+QkWUpRKcCCzbVTXBzQ2t1ng8RTjsclnLwLysnSpLJvGfko8hq30rU9HJVq4 /languages/ebnf.js
sha384-LT6ea03Ihj20gYuU/bfouACcd8rNgZAohWItMlIwiS8CUEIBt5BEeVBZj/Xzngp/ /languages/ebnf.min.js
sha384-r7qcABiwqGhFWIM6ow6S2NwC6KkQtyvyl+UPsL5B/7GHqqqkEbfJOJEAsqzlSY5I /languages/elm.js
sha384-IKAy8uG+2GJ7OKT8sMCyI+irjkHsROGLhUVfVtbTXwtjibq81wfzBddeahMGbprC /languages/elm.min.js
sha384-VnH0twJ1N+XQ4ORynlCOgsH/agkOZpwx6hRkwyopZh4RfUGjOdDGgSZRNF5VMnGo /languages/excel.js
sha384-yZpyX3GaZ2n2wTQboLuT4pMbAyEK+icy793eW60VdZdVZMw5g5jxArbZtFkh+6ri /languages/excel.min.js
sha384-TyO+wwW4N4hAJzWrstAH3fz5H8WTWH3fG1m+pVwociHVFElEMw5b/HkZWMZGnp+0 /languages/fortran.js
sha384-WvivEbuG+ynOu3BbbceJknlKXBqe8Va2Zo7+TgCqtErB61cfboeQHQOyMapYhkUW /languages/fortran.min.js
sha384-+MzoDtq6oRPjVT31u9PHQJ7pQcmrnmZAH7q6P9XTRaMyiQzYaqq8QB6OusLjKj02 /languages/fsharp.js
sha384-v78fkUxICHap3erbZ72DyAoBlRVfNKVpjsG2fwRS+ELQNoSWDe0ppa1vTktch8gy /languages/fsharp.min.js
sha384-lDCjdnxlW/GRZYzy4Zqkj833wJD7Hc2FP927RAtySEdrShMiUSXsWuFy1IC02qxU /languages/go.js
sha384-WmGkHEmwSI19EhTfO1nrSk3RziUQKRWg3vO0Ur3VYZjWvJRdRnX4/scQg+S2w1fI /languages/go.min.js
sha384-uJvOtRh6Fp9wx3dReW/zN99lBKmJIKmncfPe+mozMr16yTE2ImLdRdn0EylcNx1z /languages/golo.js
sha384-kBAfOJR5u7K4rRCe6XBgmGfW0P+CxzQoUjt2HiIDym3zmASPuDPObmtAXxDG+2Lz /languages/golo.min.js
sha384-vfTjgSZcL3SaB+N5397Yp0A1gp7blEH1eNjC1q5c+NfNyJK78P5OYvmtZfv39LA3 /languages/gradle.js
sha384-6TGxjdrZB3xEK6UL4EcWt1IQb2v4GpvxFzOBntkuOlDC688Rf5gqq5XTWJzO1izc /languages/gradle.min.js
sha384-ow3d32gzhvqfj5wlYXK68qFqHd99nym/Rmfwu/JegRYEk9tpbiEV38q+STNcNMKJ /languages/groovy.js
sha384-N2BpqybE0W3/jhUPUCcAr9I33RlAVfy/E+lEPCSY+NLvXJdrOUWK5+/ocIoPmA64 /languages/groovy.min.js
sha384-g/lhU6FXH73RQL4eFwkPk4CuudGpbHg6cyVZCRpXft3EKCrcQTToBVEDRStjYWQb /languages/http.js
sha384-wt2eEhJoUmjz8wmTq0k9WvI19Pumi9/h7B87i0wc7QMYwnCJ0dcuyfcYo/ui1M6t /languages/http.min.js
sha384-JSUMPR+WT0h/7NlqXi1Al9bVlNT31AeZNpAHttuzu+r02AmxePeqvsZkKqYZf06n /languages/ini.js
sha384-QrHbXsWtJOiJjnLPKgutUfoIrj34yz0+JKPw4CFIDImvaTDQ/wxYyEz/zB3639vM /languages/ini.min.js
sha384-pYIeBYeCE96U9EkPcT4uJjNWyrB1BKB41JIadYJbvmGa5KacaoXtSQOUpBfeyWQX /languages/java.js
sha384-uUg+ux8epe42611RSvEkMX2gvEkMdw+l6xG5Z/aQriABp38RLyF9MjDZtlTlMuQY /languages/java.min.js
sha384-vJxw3XlwaqOQr8IlRPVIBO6DMML5W978fR21/GRI5PAF7yYi2WstLYNG1lXk6j9u /languages/javascript.js
sha384-44q2s9jxk8W5N9gAB0yn7UYLi9E2oVw8eHyaTZLkDS3WuZM/AttkAiVj6JoZuGS4 /languages/javascript.min.js
sha384-/y3ED9ClCKWhLJRddCiDiig0BhfVYRvJs8doJ3tnHsFTxeHect3A6odC84mYCzIF /languages/jboss-cli.js
sha384-l/9Uw2IKYxqWShUl/tjB8ntQuuyvxl+Y6SjEVbTZPuDxgQBWWFk3/L+a9Xq3kdRv /languages/jboss-cli.min.js
sha384-dq9sY7BcOdU/6YaN+YmFuWFG8MY2WYJG2w3RlDRfaVvjdHchE07Ss7ILfcZ56nUM /languages/json.js
sha384-RbRhXcXx5VHUdUaC5R0oV+XBXA5GhkaVCUzK8xN19K3FmtWSHyGVgulK92XnhBsI /languages/json.min.js
sha384-UjoANPpyYDKhhXCD7M94TUBIvEg+Yey//mTGwAKIPkAcmpT4QVk8D47YYWumt/ZR /languages/kotlin.js
sha384-vfngjS9mwSs6HkzR9wU3mDDip7sa8TLKAxsuQ9+ncUHU25slHzHOdx/0FWxvbg4I /languages/kotlin.min.js
sha384-0DF4M/uGwA0TYtI4/4/Nxlz/Z6TObHvf/Uhz39xsvP8TkITbNVOVhbxyOXgyUn2V /languages/latex.js
sha384-0ZgcpgIDZoDPMdyG1FHnl/MByMKt+W52UltboQpuA52+f4pniKOMFXfIfe4K4Byc /languages/latex.min.js
sha384-L+/8jDq2xFnFlaL5asbKO5pHOpaRojPndHjL9uvQ0QDo3KXeAsCdhkETUkDPLOsC /languages/ldif.js
sha384-6K5LosLSpBmsgch8WDi4VAu8AFGGqFHLbaj8VyhpemdlB1u4nq5f9JMVU7mECgFN /languages/ldif.min.js
sha384-1c9TXIjKaFE96Q8dzV+3AF30su8LWfRZ6/PIqg1gPNQo+LMeGHwB602qIjQQ+CgC /languages/less.js
sha384-nT7qGhTl7ILVe2/0D834KL+fN+VL4uJg7GFmHHF8YMIg3LSbOrihvebWz6A6KLMD /languages/less.min.js
sha384-LmfE+sO0d5qZL2Ka0DIrgJ/5U1plo4uFFAmgjcMxrQO+RkeWVYWuaphHAdrY9g7V /languages/makefile.js
sha384-NIrob3StFQyD/nlOsXVCeRsJ0N2SvFEDjFtYS393wbD3CY1eT+2kwT4RL7tpMMhs /languages/makefile.min.js
sha384-U+zIQPoVdPCO0o4poik2hYNbHtNm+L5OojDTulgIeEZTNz+LooLAm72d66mNjwKD /languages/markdown.js
sha384-mCUujHHbWJEjcupTTfWOk9YR3YCYNHaA578+TTXUd4LPi7fGNuMQbysbl1pmcIGd /languages/markdown.min.js
sha384-NKxL9la40gyvGCP5oLrJcIJDWXXv2FJc9aatPho9P/PAH1IcOBIcklePMhGDlI6x /languages/matlab.js
sha384-KveG8st4Ls4iaD1XzpsBzVc7g2K6kxnbxlZOy9cH6Knla0ZH9jsloP8nOOs6WYMP /languages/matlab.min.js
sha384-OtoDZeQykEsQoFzaA50vgmgr+D3F8WIaXZ0CZfYFivHEpkwCpRKT5Ptmuhjr5bfJ /languages/nginx.js
sha384-p6UV3HZc7zs9wUF6j4Knk3bpx1/JnhlwDoFnKJAOogB1cUi32u31NlnZ2s2dW8IR /languages/nginx.min.js
sha384-Cc1k3KuhHQqdKFz/qLsQbf9E1rahGF9daZ9proh9kVL6eww2g3xEHhMLe7YQka0z /languages/objectivec.js
sha384-laCnSBtpGFl9ww6pMsbiDiJocbu+HlV9qgfWjOoArDqQrnlxH3Qm9kia5N2cicKM /languages/objectivec.min.js
sha384-YKOtRjfzHo4SHG+iI5acI0B8GrsAlqbQpZzAKKR/oABDfo0Qw6fdjwWtHY1He+ih /languages/perl.js
sha384-J8kCjl82Po/VNpumPop593F3EckTvJlnUS2ugGW46Zjts8BPGl6iNkXjcenKcwCx /languages/perl.min.js
sha384-FbyEf9EotuzOvgY88yzeCiAnYTkV2uHiY+FkYU9uH1jJY/DmF8IvxDo0rnl4n3ug /languages/pgsql.js
sha384-Oo+KBAbqcXAtR0/yFlZsRvJSAITfvxhJ761p5yOO4pyEtYO6n/5j6eVI1dG8aGct /languages/pgsql.min.js
sha384-S1JDGPScVg8ikNKLZc4CSP0ZxLiJ7bOJMzTLfOzQiCxR6wPqAa+YtauHJXQpc2GV /languages/php.js
sha384-c1RNlWYUPEU/QhgCUumvQSdSFaq+yFhv3VfGTG/OTh8oirAi/Jnp6XbnqOLePgjg /languages/php.min.js
sha384-56Iyz0oX8ZJZPmm/9pflGG2cVp/0NER9AEbckNsLoTXXK5uMPpVWUkf/WL1BPzEb /languages/php-template.js
sha384-i5dGKRLoml9823i21v5ltbNFQCB7OAwkUve4TaJrwSnXRQ1kOjT+Wa8jX/EOj434 /languages/php-template.min.js
sha384-IHapUcPkNR+7JNsR+qYSVYGCE3Dpzo2//VYWtmGYrw3eQG1RItQ7HYq6aK1Jo/6L /languages/plaintext.js
sha384-ofjxHpechXkaeQipogSyH62tQNaqAwQiuUHOVi4BGFsX5/KectIoxz16f8J/P5U0 /languages/plaintext.min.js
sha384-BW3J/7iREOC3EuqJwzGkDJb6FY9bVvkt70ipieV892fYAp8uReDMiO0/lrUPmkzL /languages/powershell.js
sha384-LWJZQx0dgGhEK7snfNYrQs5K+QKD1sOmE02sOQCz4br9UmqSJDvPLoUVFaUyFnjq /languages/powershell.min.js
sha384-Y7fCEK9d6FMDmCjwDk8aYkwBT81VlLsGkRgL69rWbSyYdNQ2dYzDqGsrvDzlDzXw /languages/profile.js
sha384-7wPGltVO/JeXBh24riKqUEDrRGzBtEoJAIxLFV7EnTtBzHRpWXv1VhUfuAgW3tVQ /languages/profile.min.js
sha384-NKkO1gNQ8VMU2V+XXBsVWRCIZrKnCkWzbENE3b2bzgP4Ft/zybEvc9VjPhlJZWHw /languages/properties.js
sha384-tlJaeulTOJz9iqadCPTY2JwJVayIS3pMaQkEOgibHjwjmI6Fve8TLKvsR8tfmKwa /languages/properties.min.js
sha384-z9/ZgavB8oSmMO03wcEMuvJ+ypnVrLSTLGlsmLxdTl3ojio11alM7BUv47naFG9g /languages/puppet.js
sha384-fGC9yhxS2ALC1B7VH3QJtJB74sL8L9HGTepwFeHWnStwNBaEG76aCmL4Ll/dG3r8 /languages/puppet.min.js
sha384-jPbdNpWU02fvOVWuC5+6O7R5wreiTVjHAZp7aObLy1pnzr+PBEzsyolh1hbRb3vX /languages/purebasic.js
sha384-0fGNJrsJnJM+bCoqEWD8wAjBnTVkiiieYzUytYZ2EjwMDmyp+bky2QVw4w5QmqZZ /languages/purebasic.min.js
sha384-zdZio5RcGiKQJCpe/1IXujPle3bIY8sbmvCabSU5G5GzWAzZtoRZfg9QAQXCL08q /languages/python.js
sha384-IP4vv4Aoh9Lyg8QyzVkAmn2JGoDCpgVHzVSrD3Z+rVyn7+s4wx4pRjv+go3TEwfj /languages/python.min.js
sha384-7jEUoPRiHUgJOTai1kMkoxn2EnF86LMvN/MagHBb2SlmmV6Xd4jlrgQfLTzgM3sP /languages/python-repl.js
sha384-bKSBGjy2/8jltjSAlvCjAvEvjy8osMZfj37sBThcXS7n6SppraMRghmLmAxiapyN /languages/python-repl.min.js
sha384-AE7f30oAuQtqmFee9hPd2uoo44ZkyUY2wQL7DjjENhh2wrvS6q4mpxGtAxeCxiRQ /languages/ruby.js
sha384-pFZpTUpdH4YEXSenc9hfKZ4uCv2IQoJQCIlIHpA0fM2cvTVH8LuzQMNcGSRGeJG0 /languages/ruby.min.js
sha384-CA6FQ5i08WYjgGIhQBrXKmcJg42apGjTP9b5WqttVw3cYEtXwHHGo+XJLYS7u7F2 /languages/rust.js
sha384-ZQJ5PCEftpFqCZkLDs96CSDGddxBultwqTdlxjnJ5h2doMAQv0n1x66w7T/JQEyy /languages/rust.min.js
sha384-fTEZwIYHuPF/IPt/9cYmUOxedtwV1lgf7s8YR0WCalv3x1IyOOs9x2fU9MmatJ9e /languages/scala.js
sha384-tbWlb460xfE9lNi4sNjNnZ4Btfos1He7bWO+9UmtNq4TwJ7F7nX8gaR0e6sVJsUk /languages/scala.min.js
sha384-KW3ZDReTAemYUfVHvH1MNQ/v6agCYYdMGdMteP/yVV+NetIJeDMx0ruUMTbr/SD3 /languages/shell.js
sha384-PDEMny3uYpCrSKwqVGLAwqCsc9u+9hYXauxVPqO6RXmlxSNKLoRByEBigU5lahmK /languages/shell.min.js
sha384-Dy7I/j0yJlyliWiNrkNqXfxDrbN65q40s3JColgTYZQ7QJa7lcmK0WUL3i00/T51 /languages/sql.js
sha384-8q00eP+tyV9451aJYD5ML3ftuHKsGnDcezp7EXMEclDg1fZVSoj8O+3VyJTkXmWp /languages/sql.min.js
sha384-M6Xb+A01UtgwR4nr8CBs6F51q0xe6hLSjT0AErnSSBeYKnEYWLmsaCn2H+WF/96/ /languages/twig.js
sha384-+o+wt9LKrJr093fuXe59myi53sotEZ0z9+zFloHncK3RudScyrwBfGFj8oW5urR+ /languages/twig.min.js
sha384-yZXtQC/OmWoPykosK7vE1nCvV4E/six6+apjNau4JwBkejkea5nP7VBEJJkGnvoF /languages/typescript.js
sha384-ORwtVEfrCZ0gzGacgmfv1wOtxcPIaVfHKwq8dKQjObRwx3qpKjsSg1ldTu1PEgXd /languages/typescript.min.js
sha384-eq5Hd6gkTe5WGbF4XH+7WuiNnuq2zbdo/CV5idmTs5HIdlT6nsfGAJeb2aBqsRO6 /languages/vim.js
sha384-WcP1nsZR09ttNCYSUJGb4LmXw+/kA1O2iyojERHIrTB7Ou0ONLTsIkFOnFF2Umkj /languages/vim.min.js
sha384-+PuZYFfVX2UQZU2yKt/FsJUZNUPzZWxW7auXltsaecr1xLvzBYF3c5gYoyOs1++x /languages/xml.js
sha384-jgkY4GMNWfQcLLIoP1vg3FWXflDrRhcSXGBW6ONIWC2SOIv5H1Pa57sXs+aomCuZ /languages/xml.min.js
sha384-qAZyZ+qLtpKyZRi1fBDgPuTTRxxU1wH9vU2LswnyagOc+g+76LeS6Hk0XkLiJ3QC /languages/xquery.js
sha384-6LS0FTqNBhJALRfpBWUybxuisiSomzK/oLOq6RTNev4R8oJiK2qiX4Liae/Zszmz /languages/xquery.min.js
sha384-tB5cwwsX4Ddp7P4d+ZInDb3nt4ihEEglHXoQ18eVLlT7soEn7bfGfABWKIn1l+H2 /languages/yaml.js
sha384-WC56y8OaFPt5Kj2HX6JAumxUYEjQmBDcSTJy2pn/N8g7dg1hKjeNVrJYoxlpeVmz /languages/yaml.min.js
sha384-p9SmfMXsdV8cXdpOKUJuPEG+ntPXcV2554BlDfczxM5wnnAFkrUVYJK4oiK5w1XV /highlight.js
sha384-T6ruaLV65fOug3LSC/qZVeCbNtio7t4WcsjTeGwmfXkqGSoxQZgtZm+XwHwfG2Ig /highlight.min.js
```

